/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Defines the possible orientations for ActionSheet action buttons.
 * - `horizontal`&mdash;Lays out actions in a horizontal row.
 * - `vertical`&mdash;Stacks actions vertically.
 */
export type ActionSheetActionsOrientation = 'horizontal' | 'vertical';
/**
 * Defines the possible alignments for the ActionSheet action buttons.
 * - `start`&mdash;Aligns actions to the start of the container.
 * - `center`&mdash;Centers actions within the container.
 * - `end`&mdash;Aligns actions to the end of the container.
 * - `stretched`&mdash;Stretches actions to fill the available space.
 * - `justify`&mdash;Distributes actions evenly across the container.
 */
export type ActionSheetActionsAlignment = 'start' | 'center' | 'end' | 'stretched' | 'justify';
/**
 * Represents the layout configuration options for the ActionSheet action buttons.
 */
export interface ActionSheetActionsLayout {
    /**
     * Specifies the orientation of the actions.
     *
     * @default horizontal
     */
    orientation?: ActionSheetActionsOrientation;
    /**
     * Specifies the alignment of the actions within the container.
     *
     * @default stretched
     */
    alignment?: ActionSheetActionsAlignment;
}
