/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ButtonFillMode, ButtonSize, ButtonThemeColor } from "@progress/kendo-angular-buttons";
import { SVGIcon } from "@progress/kendo-svg-icons";
/**
 * Describes the configuration for an ActionSheet action button.
 */
export interface ActionSheetAction {
    /**
     * Specifies the unique identifier of the action button.
     */
    id?: string | number;
    /**
     * Sets the text content of the action button.
     */
    text?: string;
    /**
     * Sets the [font icon](slug:icon_list) for the action button.
     */
    icon?: string;
    /**
     * Specifies an [`SVGIcon`](slug:api_icons_svgicon) for the action button.
     */
    svgIcon?: SVGIcon;
    /**
     * Specifies the `title` attribute for the action button. The title appears as the default tooltip.
     */
    title?: string;
    /**
     * Sets the size of the action button.
     */
    size?: ButtonSize;
    /**
     * Defines the fill mode of the action button.
     */
    fillMode?: ButtonFillMode;
    /**
     * Specifies the theme color of the action button.
     */
    themeColor?: ButtonThemeColor;
}
