/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ActionSheetItemGroup } from "./group";
/**
 * Represents the configuration for an ActionSheet item.
 */
export interface ActionSheetItem {
    /**
     * Specifies the text content of the ActionSheet item.
     */
    title?: string;
    /**
     * Defines the name of an existing [font icon](slug:icon_list) to render inside the item. The icon is rendered in a `span.k-icon` element.
     */
    icon?: string;
    /**
     * Defines an [`SVGIcon`](slug:api_icons_svgicon) to render within the ActionSheet item.
     */
    svgIcon?: SVGIcon;
    /**
     * Defines one or more CSS classes to apply to a span element inside the item. Allows using custom icons.
     */
    iconClass?: string;
    /**
     * Specifies the group for the item. Use `top` to render the item above the separator, or `bottom` to render below it.
     */
    group?: ActionSheetItemGroup;
    /**
     * Sets additional text rendered below the item's title.
     */
    description?: string;
    /**
     * Specifies whether the ActionSheet item is initially disabled.
     *
     * @default false
     */
    disabled?: boolean;
    /**
     * Defines the size of the icon. Accepts any valid CSS font-size value.
     */
    iconSize?: string;
    /**
     * Sets the color of the icon. Accepts `inherit`, `default`, `primary`, `secondary`, `tertiary`, `info`, `success`, `warning`, `error`, `dark`, `light`, `inverted`, or any hexadecimal value.
     */
    iconColor?: string;
    /**
     * Specifies the CSS classes to apply to the item. Supports all value types accepted by [`ngClass`](link:site.data.urls.angular['ngclassapi']).
     */
    cssClass?: any;
    /**
     * Specifies the CSS styles to apply to the item. Supports all value types accepted by [`ngStyle`](link:site.data.urls.angular['ngstyleapi']).
     */
    cssStyle?: any;
}
