/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Renderer2, ElementRef, AfterViewInit } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI AppBarSpacer component for Angular]({% slug contentarrangement_appbar %}#toc-spacings).
 *
 * Use the AppBarSpacer component to add white space between AppBar sections and customize its width.
 *
 * @example
 * ```html
 * <kendo-appbar>
 *    <kendo-appbar-section>
 *        <button kendoButton fillMode="flat" [svgIcon]="menuIcon"></button>
 *    </kendo-appbar-section>
 *
 *    <kendo-appbar-spacer></kendo-appbar-spacer>
 *
 *     <kendo-appbar-section>
 *          <h2>Page Title</h2>
 *     </kendo-appbar-section>
 * </kendo-appbar>
 * ```
 */
export declare class AppBarSpacerComponent implements AfterViewInit {
    private renderer;
    private element;
    hostClass: boolean;
    get sizedClass(): boolean;
    /**
     * Specifies the width of the AppBarSpacer.
     *
     * If not set, the AppBarSpacer will take all of the available space.
     */
    width: string;
    constructor(renderer: Renderer2, element: ElementRef);
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppBarSpacerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AppBarSpacerComponent, "kendo-appbar-spacer", never, { "width": { "alias": "width"; "required": false; }; }, {}, never, never, true, never>;
}
