/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterViewInit, ElementRef, OnDestroy, Renderer2 } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { AppBarPosition } from './models/position';
import { AppBarThemeColor } from './models/theme-color';
import { AppBarPositionMode } from './models/position-mode';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI AppBar component for Angular]({% slug overview_appbar %}).
 *
 * Use the AppBar component to display information, actions, brand titles, and additional navigation on the current screen.
 *
 * @example
 * ```html
 * <kendo-appbar>
 *    <kendo-appbar-section>
 *        <h2>Page Title</h2>
 *    </kendo-appbar-section>
 * </kendo-appbar>
 * ```
 *
 * @remarks
 * Supported children components are: {@link AppBarSectionComponent}, {@link AppBarSpacerComponent}
 */
export declare class AppBarComponent implements AfterViewInit, OnDestroy {
    private localizationService;
    private host;
    private renderer;
    hostClass: boolean;
    /**
     * @hidden
     */
    direction: string;
    /**
     * Specifies the position of the AppBar
     * ([see example]({% slug positioning_appbar %}#toc-position)).
     *
     * @default 'top'
     */
    set position(position: AppBarPosition);
    get position(): AppBarPosition;
    /**
     * Sets the position mode of the AppBar ([see example](slug:positioning_appbar#toc-position-mode)).
     *
     * @default 'static'
     */
    set positionMode(positionMode: AppBarPositionMode);
    get positionMode(): AppBarPositionMode;
    /**
     * Sets the theme color of the AppBar. The theme color is applied as the background color of the component.
     *
     * @default 'light'
     */
    set themeColor(themeColor: AppBarThemeColor);
    get themeColor(): AppBarThemeColor;
    private dynamicRTLSubscription;
    private rtl;
    private _themeColor;
    private _position;
    private _positionMode;
    constructor(localizationService: LocalizationService, host: ElementRef, renderer: Renderer2);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    private handleHostClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppBarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AppBarComponent, "kendo-appbar", ["kendoAppBar"], { "position": { "alias": "position"; "required": false; }; "positionMode": { "alias": "positionMode"; "required": false; }; "themeColor": { "alias": "themeColor"; "required": false; }; }, {}, never, ["*"], true, never>;
}
