/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SVGIcon } from "@progress/kendo-svg-icons";
/**
 * Describes the structure of a BottomNavigation item ([see example](slug:items_bottomnavigation)).
 */
export interface BottomNavigationItem {
    /**
     * Disables the BottomNavigation item.
     *
     * @default false
     */
    disabled?: boolean;
    /**
     * Defines the name of an existing [font icon](slug:icon_list) in a Kendo UI theme.
     */
    icon?: string;
    /**
     * Applies a CSS class or multiple classes separated by spaces to a span element inside the item. Allows the usage of custom icons.
     */
    iconClass?: string;
    /**
     * Sets an [`SVGIcon`](slug:api_icons_svgicon) to render within the BottomNavigation item.
     */
    svgIcon?: SVGIcon;
    /**
     * Specifies whether the BottomNavigation item is selected.
     */
    selected?: boolean;
    /**
     * Sets the `tabindex` attribute of the BottomNavigation item.
     *
     * @default 0
     */
    tabIndex?: number;
    /**
     * Sets the text content of the BottomNavigation item.
     */
    text?: string;
    /**
     * Applies CSS classes to the item element of the BottomNavigation. Supports the type of values that are supported by [`ngClass`](link:site.data.urls.angular['ngclassapi']).
     */
    cssClass?: any;
    /**
     * Applies CSS styles to the item element of the BottomNavigation. Supports the type of values that are supported by [`ngStyle`](link:site.data.urls.angular['ngstyleapi']).
     */
    cssStyle?: any;
}
