/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SVGIcon } from "@progress/kendo-svg-icons";
/**
 * @hidden
 */
interface BreadCrumbItemContext {
    collapsed: boolean;
    isLast: boolean;
    isFirst: boolean;
}
/**
 * @hidden
 */
export interface BreadCrumbItemModel {
    context: BreadCrumbItemContext;
    data: BreadCrumbItem;
}
/**
 * Represents an interface that defines the structure of individual Breadcrumb items.
 */
export interface BreadCrumbItem {
    /**
     * Sets the text content for the item. If not provided, the numeric item index appears by default.
     */
    text?: string;
    /**
     * Provides a title for the item ([see example]({% slug overview_breadcrumb %})). The value appears as a `title` attribute on the element.
     */
    title?: string;
    /**
     * Determines if the item is disabled ([see example]({% slug item_appearance_breadcrumb %})#toc-disabled-items). The value appears as an `aria-disabled` attribute on the element.
     *
     * @default false
     */
    disabled?: boolean;
    /**
     * Specifies the name of a [built-in font icon](slug:icon_list) in a Kendo UI theme ([see example](slug:item_appearance_breadcrumb#toc-displaying-font-icons)). The icon appears inside the item in a `span.k-icon` element.
     */
    icon?: string;
    /**
     * Sets an [`SVGIcon`](slug:api_icons_svgicon) to display inside the item ([see example](slug:item_appearance_breadcrumb#toc-displaying-svg-icons)).
     */
    svgIcon?: SVGIcon;
    /**
     * Applies one or more CSS classes to a `span` element inside the item ([see example](slug:item_appearance_breadcrumb#toc-displaying-font-icons)). Use this to show custom icons.
     */
    iconClass?: string;
    /**
     * Provides a URL for an `img` element inside the item ([see example](slug:item_appearance_breadcrumb#toc-displaying-item-images)). The URL can be relative or absolute. If relative, it is resolved against the web page URL.
     */
    imageUrl?: string;
}
export {};
